.. :changelog:

History
=======

0.3.0
-----

Released: 2016-03-30
Status: Alpha

* First release on pypi
* Significant redesign from 0.2.0
* Configuration tree model

0.2.0
-----

Released: 2014-09-17
Status: Pre-alpha

* First release on github
